@@ -12,7 +12,7 @@
  *     file semantics.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_string_c[] = "$Id: string.c 12356 2010-12-23 20:30:41Z wsfulton $";
+char cvsroot_string_c[] = "$Id: string.c 12536 2011-03-14 07:22:08Z wsfulton $";
 
 #include "dohint.h"
 
@@ -269,7 +269,6 @@ static void String_clear(DOH *so) {
 
 static int String_insert(DOH *so, int pos, DOH *str) {
   String *s;
-  char *nstr;
   int len;
   char *data;
 
@@ -289,7 +288,6 @@ static int String_insert(DOH *so, int pos, DOH *str) {
     data = (char *) (str);
     len = (int) strlen(data);
   }
-  nstr = s->str;
 
   if (pos < 0)
     pos = 0;
