@@ -1,5 +1,5 @@
-/* ----------------------------------------------------------------------------- 
- * This file is part of SWIG, which is licensed as a whole under version 3 
+/* -----------------------------------------------------------------------------
+ * This file is part of SWIG, which is licensed as a whole under version 3
  * (or any later version) of the GNU General Public License. Some additional
  * terms also apply to certain portions of SWIG. The full details of the SWIG
  * license and copyrights can be found in the LICENSE and COPYRIGHT files
@@ -60,6 +60,7 @@
 #define WARN_PP_INCLUDEALL_IMPORTALL  203
 #define WARN_PP_CPP_WARNING           204
 #define WARN_PP_CPP_ERROR             205
+#define WARN_PP_UNEXPECTED_TOKENS     206
 
 /* -- C/C++ Parser -- */
 
@@ -193,14 +194,37 @@
 #define WARN_LANG_DIRECTOR_ABSTRACT   517
 #define WARN_LANG_PORTABILITY_FILENAME 518
 #define WARN_LANG_TEMPLATE_METHOD_IGNORE 519
+#define WARN_LANG_SMARTPTR_MISSING    520
 
 /* -- Reserved (600-799) -- */
 
-/* -- Language module specific warnings (800 - 999) -- */
+/* -- Language module specific warnings (700 - 899) -- */
+
+/* Feel free to claim any number in this space that's not currently being used. Just make sure you
+   add an entry here */
+
+#define WARN_D_TYPEMAP_CTYPE_UNDEF           700
+#define WARN_D_TYPEMAP_IMTYPE_UNDEF           701
+#define WARN_D_TYPEMAP_DTYPE_UNDEF           702
+#define WARN_D_MULTIPLE_INHERITANCE           703
+#define WARN_D_TYPEMAP_CLASSMOD_UNDEF         704
+#define WARN_D_TYPEMAP_DBODY_UNDEF            705
+#define WARN_D_TYPEMAP_DOUT_UNDEF             706
+#define WARN_D_TYPEMAP_DIN_UNDEF              707
+#define WARN_D_TYPEMAP_DDIRECTORIN_UNDEF      708
+#define WARN_D_TYPEMAP_DCONSTRUCTOR_UNDEF     709
+#define WARN_D_EXCODE_MISSING                 710
+#define WARN_D_CANTHROW_MISSING               711
+#define WARN_D_NO_DIRECTORCONNECT_ATTR        712
+#define WARN_D_NAME_COLLISION                 713
+
+/* please leave 700-719 free for D */
 
 #define WARN_RUBY_WRONG_NAME                  801
 #define WARN_RUBY_MULTIPLE_INHERITANCE        802
 
+/* please leave 800-809 free for Ruby */
+
 #define WARN_JAVA_TYPEMAP_JNI_UNDEF           810
 #define WARN_JAVA_TYPEMAP_JTYPE_UNDEF         811
 #define WARN_JAVA_TYPEMAP_JSTYPE_UNDEF        812
@@ -258,8 +282,10 @@
 
 /* please leave 870-889 free for PHP */
 
+#define WARN_GO_NAME_CONFLICT                 890
 
-/* Feel free to claim any number in this space that's not currently being used. Just make sure you
-   add an entry here */
+/* please leave 890-899 free for Go */
+
+/* -- User defined warnings (900 - 999) -- */
 
 #endif
