@@ -15,7 +15,7 @@
  * Doc/Manual/SWIGPlus.html for details.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_allocate_cxx[] = "$Id: allocate.cxx 12458 2011-02-13 16:33:12Z wsfulton $";
+char cvsroot_allocate_cxx[] = "$Id: allocate.cxx 12536 2011-03-14 07:22:08Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -386,10 +386,6 @@ class Allocate:public Dispatcher {
     }
 
     Node *c = firstChild(cls);
-    String *kind = Getattr(cls, "kind");
-    int mode = PUBLIC;
-    if (kind && (Strcmp(kind, "class") == 0))
-      mode = PRIVATE;
 
     while (c) {
       if (Getattr(c, "error") || GetFlag(c, "feature:ignore")) {
@@ -457,13 +453,6 @@ class Allocate:public Dispatcher {
 	}
       }
 
-      if (Strcmp(nodeType(c), "access") == 0) {
-	kind = Getattr(c, "kind");
-	if (Strcmp(kind, "public") == 0)
-	  mode = PUBLIC;
-	else
-	  mode = PRIVATE;
-      }
       c = nextSibling(c);
     }
     /* Look for methods in base classes */
