@@ -1,13 +1,17 @@
 /* -----------------------------------------------------------------------------
- * See the LICENSE file for information on copyright, usage and redistribution
- * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ * This file is part of SWIG, which is licensed as a whole under version 3 
+ * (or any later version) of the GNU General Public License. Some additional
+ * terms also apply to certain portions of SWIG. The full details of the SWIG
+ * license and copyrights can be found in the LICENSE and COPYRIGHT files
+ * included with the SWIG source code as distributed by the SWIG developers
+ * and at http://www.swig.org/legal.html.
  *
  * cffi.cxx
  *
  * cffi language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_cffi_cxx[] = "$Id: cffi.cxx 11136 2009-02-20 23:55:37Z wsfulton $";
+char cvsroot_cffi_cxx[] = "$Id: cffi.cxx 12524 2011-03-09 21:42:38Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -16,6 +20,19 @@ char cvsroot_cffi_cxx[] = "$Id: cffi.cxx 11136 2009-02-20 23:55:37Z wsfulton $";
 //#define CFFI_DEBUG
 //#define CFFI_WRAP_DEBUG
 
+static const char *usage = (char *) "\
+CFFI Options (available with -cffi)\n\
+     -generate-typedef - Use defctype to generate shortcuts according to the\n\
+                         typedefs in the input.\n\
+     -[no]cwrap        - Turn on or turn off generation of an intermediate C\n\
+                         file when creating a C interface. By default this is\n\
+                         only done for C++ code.\n\
+     -[no]swig-lisp    - Turn on or off generation of code for helper lisp\n\
+                         macro, functions, etc. which SWIG uses while\n\
+                         generating wrappers. These macros, functions may still\n\
+                         be used by generated wrapper code.\n\
+";
+
 class CFFI:public Language {
 public:
   String *f_cl;
@@ -76,17 +93,7 @@ void CFFI::main(int argc, char *argv[]) {
   CWrap = false;
   for (i = 1; i < argc; i++) {
     if (!Strcmp(argv[i], "-help")) {
-      Printf(stdout, "cffi Options (available with -cffi)\n");
-      Printf(stdout,
-       "   -generate-typedef\n"
-       "\tIf this option is given then defctype will be used to generate\n"
-       "\tshortcuts according to the typedefs in the input.\n"
-       "   -[no]cwrap\n"
-       "\tTurn on or turn off generation of an intermediate C file when\n"
-       "\tcreating a C interface. By default this is only done for C++ code.\n"
-       "   -[no]swig-lisp\n"
-       "\tTurns on or off generation of code for helper lisp macro, functions,\n"
-       "\tetc. which SWIG uses while generating wrappers. These macros, functions\n" "\tmay still be used by generated wrapper code.\n");
+      Printf(stdout, "%s\n", usage);
     } else if (!strcmp(argv[i], "-cwrap")) {
       CWrap = true;
       Swig_mark_arg(i);
@@ -618,12 +625,12 @@ int CFFI::enumDeclaration(Node *n) {
     slot_name_keywords = true;
 
     //Registering the enum name to the cin and cout typemaps
-    Parm *pattern = NewParm(name, NULL);
+    Parm *pattern = NewParm(name, NULL, n);
     Swig_typemap_register("cin", pattern, lisp_name, NULL, NULL);
     Swig_typemap_register("cout", pattern, lisp_name, NULL, NULL);
     Delete(pattern);
     //Registering with the kind, i.e., enum
-    pattern = NewParm(NewStringf("enum %s", name), NULL);
+    pattern = NewParm(NewStringf("enum %s", name), NULL, n);
     Swig_typemap_register("cin", pattern, lisp_name, NULL, NULL);
     Swig_typemap_register("cout", pattern, lisp_name, NULL, NULL);
     Delete(pattern);
@@ -688,7 +695,7 @@ void CFFI::emit_class(Node *n) {
   Printf(f_clos, "\n(cl:defclass %s%s", lisp_name, supers);
   Printf(f_clos, "\n  ((ff-pointer :reader ff-pointer)))\n\n");
 
-  Parm *pattern = NewParm(Getattr(n, "name"), NULL);
+  Parm *pattern = NewParm(Getattr(n, "name"), NULL, n);
 
   Swig_typemap_register("lispclass", pattern, lisp_name, NULL, NULL);
   SwigType_add_pointer(Getattr(pattern, "type"));
@@ -758,7 +765,7 @@ void CFFI::emit_class(Node *n) {
   Delete(supers);
   //  Delete(ns_list);
 
-  //  Parm *pattern = NewParm(name,NULL);
+  //  Parm *pattern = NewParm(name, NULL, n);
   // Swig_typemap_register("cin",pattern,lisp_name,NULL,NULL);  
   //Swig_typemap_register("cout",pattern,lisp_name,NULL,NULL);
   //Delete(pattern);
@@ -787,12 +794,12 @@ void CFFI::emit_struct_union(Node *n, bool un = false) {
 
   //Register the struct/union name to the cin and cout typemaps
 
-  Parm *pattern = NewParm(name, NULL);
+  Parm *pattern = NewParm(name, NULL, n);
   Swig_typemap_register("cin", pattern, lisp_name, NULL, NULL);
   Swig_typemap_register("cout", pattern, lisp_name, NULL, NULL);
   Delete(pattern);
   //Registering with the kind, i.e., struct or union
-  pattern = NewParm(NewStringf("%s %s", kind, name), NULL);
+  pattern = NewParm(NewStringf("%s %s", kind, name), NULL, n);
   Swig_typemap_register("cin", pattern, lisp_name, NULL, NULL);
   Swig_typemap_register("cout", pattern, lisp_name, NULL, NULL);
   Delete(pattern);
@@ -819,21 +826,24 @@ void CFFI::emit_struct_union(Node *n, bool un = false) {
       //               Getattr(c, "type"));
       //       SWIG_exit(EXIT_FAILURE);
     } else {
-      SwigType *childType = NewStringf("%s%s", Getattr(c, "decl"),
-               Getattr(c, "type"));
+      SwigType *childType = NewStringf("%s%s", Getattr(c, "decl"), Getattr(c, "type"));
 
-      Hash *typemap = Swig_typemap_search("cin", childType, "", 0);
-      String *typespec = NewString("");
-      if (typemap) {
-  typespec = NewString(Getattr(typemap, "code"));
-      }
+      Node *node = NewHash();
+      Setattr(node, "type", childType);
+      Setfile(node, Getfile(n));
+      Setline(node, Getline(n));
+      const String *tm = Swig_typemap_lookup("cin", node, "", 0);
+
+      String *typespec = tm ? NewString(tm) : NewString("");
 
       String *slot_name = lispify_name(c, Getattr(c, "sym:name"), "'slotname");
       if (Strcmp(slot_name, "t") == 0 || Strcmp(slot_name, "T") == 0)
-  slot_name = NewStringf("t_var");
+	slot_name = NewStringf("t_var");
 
       Printf(f_cl, "\n\t(%s %s)", slot_name, typespec);
 
+      Delete(node);
+      Delete(childType);
       Delete(typespec);
     }
   }
