@@ -11,7 +11,7 @@
  * Useful functions for emitting various pieces of code.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_emit_cxx[] = "$Id: emit.cxx 11980 2010-04-08 06:46:18Z wsfulton $";
+char cvsroot_emit_cxx[] = "$Id: emit.cxx 12536 2011-03-14 07:22:08Z wsfulton $";
 
 #include "swigmod.h"
 
@@ -402,7 +402,6 @@ String *emit_action(Node *n) {
   String *tm;
   String *action;
   String *wrap;
-  SwigType *rt;
   ParmList *catchlist = Getattr(n, "catchlist");
 
   /* Look for fragments */
@@ -440,9 +439,6 @@ String *emit_action(Node *n) {
     action = Getattr(n, "wrap:action");
   assert(action != 0);
 
-  /* Get the return type */
-  rt = Getattr(n, "type");
-
   /* Emit contract code (if any) */
   if (Swig_contract_mode_get()) {
     /* Preassertion */
