@@ -15,10 +15,17 @@ char cvsroot_octave_cxx[] = "$Id$";
 
 #include "swigmod.h"
 
+static bool global_load = true;
+static String *global_name = 0;
+static String *op_prefix   = 0;
+
 static const char *usage = (char *) "\
 Octave Options (available with -octave)\n\
-     [no additional options]\n\
-     \n";
+     -global         - Load all symbols into the global namespace [default]\n\
+     -globals <name> - Set <name> used to access C global variables [default: 'cvar']\n\
+     -noglobal       - Do not load all symbols into the global namespace\n\
+     -opprefix <str> - Prefix <str> for global operator functions [default: 'op_']\n\
+\n";
 
 
 class OCTAVE:public Language {
@@ -64,11 +71,40 @@ public:
     for (int i = 1; i < argc; i++) {
       if (argv[i]) {
 	if (strcmp(argv[i], "-help") == 0) {
-	  fputs(usage, stderr);
-	}
+	  fputs(usage, stdout);
+	} else if (strcmp(argv[i], "-global") == 0) {
+          global_load = true;
+          Swig_mark_arg(i);
+	} else if (strcmp(argv[i], "-noglobal") == 0) {
+          global_load = false;
+          Swig_mark_arg(i);
+	} else if (strcmp(argv[i], "-globals") == 0) {
+	  if (argv[i + 1]) {
+	    global_name = NewString(argv[i + 1]);
+	    Swig_mark_arg(i);
+	    Swig_mark_arg(i + 1);
+	    i++;
+	  } else {
+	    Swig_arg_error();
+	  }
+	} else if (strcmp(argv[i], "-opprefix") == 0) {
+	  if (argv[i + 1]) {
+	    op_prefix = NewString(argv[i + 1]);
+	    Swig_mark_arg(i);
+	    Swig_mark_arg(i + 1);
+	    i++;
+	  } else {
+	    Swig_arg_error();
+	  }
+        }            
       }
     }
 
+    if (!global_name)
+      global_name = NewString("cvar");
+    if (!op_prefix)
+      op_prefix = NewString("op_");
+
     SWIG_library_directory("octave");
     Preprocessor_define("SWIGOCTAVE 1", 0);
     SWIG_config_file("octave.swg");
@@ -131,6 +167,11 @@ public:
     Printf(f_runtime, "#define SWIG_name_d      \"%s\"\n", module);
     Printf(f_runtime, "#define SWIG_name        %s\n", module);
 
+    Printf(f_runtime, "\n");
+    Printf(f_runtime, "#define SWIG_global_load      %s\n", global_load ? "true" : "false");
+    Printf(f_runtime, "#define SWIG_global_name      \"%s\"\n", global_name);
+    Printf(f_runtime, "#define SWIG_op_prefix        \"%s\"\n", op_prefix);
+
     if (directorsEnabled()) {
       Printf(f_runtime, "#define SWIG_DIRECTORS\n");
       Swig_banner(f_directors_h);
@@ -359,13 +400,11 @@ public:
       String *name = 0;
       String *type = 0;
       String *value = 0;
-      String *ptype = 0;
       String *pdoc = Getattr(p, "tmap:doc");
       if (pdoc) {
 	name = Getattr(p, "tmap:doc:name");
 	type = Getattr(p, "tmap:doc:type");
 	value = Getattr(p, "tmap:doc:value");
-	ptype = Getattr(p, "tmap:doc:pytype");
       }
 
       name = name ? name : Getattr(p, "name");
@@ -1243,8 +1282,7 @@ public:
       // build argument list and type conversion string
       idx = 0;
       p = l;
-      int use_parse = 0;
-      while (p != NULL) {
+      while (p) {
 	if (checkAttribute(p, "tmap:in:numinputs", "0")) {
 	  p = Getattr(p, "tmap:in:next");
 	  continue;
@@ -1266,7 +1304,6 @@ public:
 	    Printf(wrap_args, "args.append(tmpv);\n");
 	    Putc('O', parse_args);
 	  } else {
-	    use_parse = 1;
 	    Append(parse_args, parse);
 	    Replaceall(tm, "$input", pname);
 	    Replaceall(tm, "$owner", "0");
